@@ -87,6 +87,8 @@ _LFoutput_fmt = [
     {'file': 'MaxHeights.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum depth', 'symbol': 't_maxh', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'MaxSpeeds.txt', 'column': 5, 'short_name': 'maximum_speed', 'long_name': 'Maximum speed of lahar', 'symbol': 'maxspd', 'units': 'm/s', 'dtype': 'real', 'infile': True, },
     {'file': 'MaxSpeeds.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum speed', 'symbol': 't_maxspd', 'units': 's', 'dtype': 'real', 'infile': True, },
+    {'file': 'MaxEorsion.txt', 'column': 5, 'short_name': 'maximum_erosion', 'long_name': 'Maximum erosion', 'symbol': 'maxero', 'units': 'm', 'dtype': 'real', 'infile': True, },
+    {'file': 'MaxEorsion.txt', 'column': 6, 'short_name': 'time_of_maximum', 'long_name': 'Time of the maximum erosion', 'symbol': 't_maxero', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'InundationTime.txt', 'column': 5, 'short_name': 'inundation_time', 'long_name': 'Time of first inundation', 'symbol': 't_inun', 'units': 's', 'dtype': 'real', 'infile': True, },
     {'file': 'Maximums.nc', 'short_name': 'maximum_depth', 'long_name': 'Maximum depth of lahar', 'symbol': 'maxh', 'units': 'm', 'dtype': 'real', 'infile': True, },
     {'file': 'Maximums.nc', 'short_name': 'time_of_max_depth', 'long_name': 'Time of the maximum depth', 'symbol': 't_maxh', 'units': 's', 'dtype': 'real', 'infile': True, },
@@ -632,6 +634,8 @@ class LaharFlowData(object):
                 filetype = 'MaxHeights.txt'
             elif filename=='MaxSpeeds.txt':
                 filetype = 'MaxSpeeds.txt'
+            elif filename=='MaxErosion.txt':
+                filetype = 'MaxErosion.txt'
             elif filename=='InundationTime.txt':
                 filetype = 'InundationTime.txt'
             elif filename=='Maximums.nc':
